__all__ = ['main', 'metadata', 'console']
__author__ = 'Christian S. Perone'
__author_url__ = 'http://pyevolve.sourceforge.net/wordpress'
__version__ = '0.4'
